#
# spec file for package python-tenacity
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
%bcond_without  test
Name:           python-tenacity
Version:        4.8.0
Release:        lp151.2.2
Summary:        Retry code until it succeeeds
License:        Apache-2.0
Group:          Development/Languages/Python
Url:            https://github.com/jd/tenacity
Source:         https://files.pythonhosted.org/packages/source/t/tenacity/tenacity-%{version}.tar.gz
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module monotonic >= 0.6}
BuildRequires:  %{python_module pbr}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module six >= 1.7.0}
BuildRequires:  fdupes
BuildRequires:  python-futures >= 3.0
BuildRequires:  python-rpm-macros
%if %{with test}
BuildRequires:  %{python_module nose}
BuildRequires:  %{python_module tornado}
%endif
Requires:       python-monotonic >= 0.6
Requires:       python-six >= 1.9.0
Recommends:     python-tornado
%ifpython2
Requires:       python-futures >= 3.0
%endif
BuildArch:      noarch

%python_subpackages

%description
Tenacity is a general-purpose retrying library, written in Python, to simplify
the task of adding retry behavior to just about anything.
It originates from a fork of `Retrying`_
Features
--------
- Generic Decorator API
- Specify stop condition (i.e. limit by number of attempts)
- Specify wait condition (i.e. exponential backoff sleeping between attempts)
- Customize retrying on Exceptions
- Customize retrying on expected returned result

%prep
%setup -q -n tenacity-%{version}

%build
%python_build

%install
%python_install
%python_expand %fdupes -s %{buildroot}%{$python_sitelib}

%if %{with test}
%check
%python_exec setup.py nosetests --ignore-files '.*async.py'
%endif

%files %{python_files}
%defattr(-,root,root,-)
%doc AUTHORS ChangeLog LICENSE README.rst
%{python_sitelib}/*

%changelog
* Wed Jan 10 2018 jengelh@inai.de
- Remove repetition of license terms in description.
* Wed Jan 10 2018 toddrme2178@gmail.com
- update to 4.8.0
  * Allow waiters to introspect last result
- update to 4.7.1
  * Missed top level import of stop\_when\_event\_set
  * Mention Tornado minimum version in README
  * Fix unless\_exception test names and add no input test
- update to 4.7.0
  * Add Tornado support
  * Fix pep8
- update to 4.6.1
  * Simplify wrapping code
- update to 4.6.0
  * Implement \`retry\_with' on decorated functions
- Implement single-spec version
* Thu Nov  2 2017 dmueller@suse.com
- update to 4.5.0:
  * Replace hacking with flake8 extensions
  * Fix import order
  * Put a default sleep attribute on BaseRetrying
  * async: allow to specify a different sleep method
  * Issue-8: Make sure doc examples run (#89)
  * Remove Python 3.4 support
* Tue Aug 22 2017 tbechtold@suse.com
- update to 4.4.0:
  * Document wait\_random\_exponential strategy
  * Rename wait\_full\_jitter to wait\_random\_exponential
  * Add retry\_unless\_exception\_type
  * Add missing ')' to README.rst
  * Do not duplicate statistics fields in instance
  * Do not start trial\_start\_time as an attribute
  * Add an example on how to combine stop conditions
  * Put a link to the GitHub issue of retrying about the fork
  * feat: added wait\_full\_jitter
  * Add new event based sleep and stop
  * Add \`wraps' method directly on Retrying object
  * wait: handle OverflowError
  * doc: raise Exception in example so they actually work
  * Remove weird example with retry\_if\_io\_error
  * Bump version for new feature
  * Add Python 3.6 support
  * Add retry\_if\_not\_result class to compliment the existing retry\_if\_result class
  * Fix six minimum version
  * doc: rewrite the before explanation
  * Add \_\_call\_\_ on BaseRetrying class
  * Document before and after keywords
  * Remove useless MANIFEST
  * Remove non-working PyPI download image
  * Bump hacking to 0.13
  * Use Python 3 for pep8 tox target
  * Remove deprecated wait\_jitter
* Fri Feb 10 2017 tbechtold@suse.com
- update to 3.7.1:
  * Fix pep8 errors
  * Correctly set the exception if we TryAgain for ever
* Sun Dec 18 2016 dmueller@suse.com
- update to 3.6.0:
  * Retry on coroutines
  * Run flake8 only with latest python
  * Deduplicate retry decorator logic
  * Extract controller IOs in subclass
  * Allow to combine stop conditions
  * Add SayThanks
  * retry: implement bitwise operators on retry strategies
  * retry: add retry_all
* Fri Dec  2 2016 dmueller@suse.com
- update to 3.4.0:
  * Deprecate wait_jitter for wait_random
  * Align tox and travis settings
  * Fix README typo
  * Bump hacking to 0.12
  * Fix README.rst wrong description
  * This is using floating point seconds (not milliseconds)
  * Some small docstring updates
  * Use py3.x compat print in README.rst
  * Fix typo in retry_if_exception example
* Wed Nov  9 2016 dmueller@suse.com
- update to 3.3.0:
  * Implement '+' operator for wait strategies
  * Rename `_retrying` attribute to `retry` and document it
  * Store retrying object as an attribute of retried function
  * Make sure statistics are thread locals
* Mon Sep 26 2016 tbechtold@suse.com
- Initial packaging (version 3.1.1)
